@@ -35,15 +35,12 @@
 #include <glib-object.h>
 #include <glib/gi18n.h>
 
-#include <gst/gst.h>
-
 #include <libtracker-miners-common/tracker-common.h>
 #include <libtracker-sparql/tracker-sparql.h>
 #include <libtracker-miner/tracker-miner.h>
 
 #include "tracker-config.h"
 #include "tracker-miner-files.h"
-#include "tracker-files-interface.h"
 
 #define ABOUT	  \
 	"Tracker " PACKAGE_VERSION "\n"
@@ -495,10 +492,12 @@ miner_finished_cb (TrackerMinerFS *fs,
                    guint           total_directories_ignored,
                    guint           total_files_found,
                    guint           total_files_ignored,
+                   guint           changes,
                    gpointer        user_data)
 {
-	g_info ("Finished mining in seconds:%f, total directories:%d, total files:%d",
+	g_info ("Finished mining in %f seconds. Changes processed: %d, inspected directories:%d, inspected files:%d",
 	        seconds_elapsed,
+	        changes,
 	        total_directories_found,
 	        total_files_found);
 
@@ -970,7 +969,6 @@ main (gint argc, gchar *argv[])
 	GMemoryMonitor *memory_monitor;
 #endif
 	gchar *domain_name, *dbus_name;
-	TrackerFilesInterface *files_interface;
 
 	main_loop = NULL;
 
@@ -986,11 +984,6 @@ main (gint argc, gchar *argv[])
 	/* This makes sure we don't steal all the system's resources */
 	initialize_priority_and_scheduling ();
 
-	/* Preempt possible registry updates, before tracker-extract-3 deals
-	 * with gstreamer plugins.
-	 */
-	gst_init (NULL, NULL);
-
 	/* Translators: this messagge will apper immediately after the
 	 * usage string - Usage: COMMAND <THIS_MESSAGE>
 	 */
@@ -1031,8 +1024,6 @@ main (gint argc, gchar *argv[])
 		return EXIT_FAILURE;
 	}
 
-	files_interface = tracker_files_interface_new (connection);
-
 	/* Initialize logging */
 	config = tracker_config_new ();
 
@@ -1199,8 +1190,6 @@ main (gint argc, gchar *argv[])
 		save_current_locale (domain_ontology);
 	}
 
-	g_object_unref (files_interface);
-
 	g_main_loop_unref (main_loop);
 	g_object_unref (config);
 
