@@ -30,6 +30,8 @@
 #include <gio/gunixinputstream.h>
 #include <gio/gunixfdlist.h>
 
+#include <libtracker-miners-common/tracker-common.h>
+
 #include <libtracker-extract/tracker-extract.h>
 
 #include "tracker-extract.h"
@@ -45,8 +47,6 @@ G_DEFINE_QUARK (TrackerExtractError, tracker_extract_error)
 
 #define DEADLINE_SECONDS 30
 
-#define DEFAULT_MAX_TEXT 1048576
-
 extern gboolean debug;
 
 typedef struct {
@@ -59,8 +59,6 @@ typedef struct {
 	GHashTable *statistics_data;
 	GList *running_tasks;
 
-	gint max_text;
-
 	/* used to maintain the running tasks
 	 * and stats from different threads
 	 */
@@ -86,7 +84,6 @@ typedef struct {
 	gchar *file;
 	gchar *mimetype;
 	const gchar *graph;
-	gint max_text;
 
 	TrackerExtractMetadataFunc func;
 	GModule *module;
@@ -127,7 +124,6 @@ tracker_extract_init (TrackerExtract *object)
 
 	priv = TRACKER_EXTRACT_GET_PRIVATE (object);
 	priv->single_thread_extractors = g_hash_table_new (NULL, NULL);
-	priv->max_text = DEFAULT_MAX_TEXT;
 
 #ifdef G_ENABLE_DEBUG
 	if (TRACKER_DEBUG_CHECK (STATISTICS)) {
@@ -291,7 +287,7 @@ get_file_metadata (TrackerExtractTask  *task,
 	*info_out = NULL;
 
 	file = g_file_new_for_uri (task->file);
-	info = tracker_extract_info_new (file, task->mimetype, task->graph, task->max_text);
+	info = tracker_extract_info_new (file, task->mimetype, task->graph);
 	g_object_unref (file);
 
 	if (!task->mimetype || !*task->mimetype) {
@@ -345,7 +341,6 @@ extract_task_new (TrackerExtract *extract,
                   GAsyncResult   *res,
                   GError        **error)
 {
-	TrackerExtractPrivate *priv = TRACKER_EXTRACT_GET_PRIVATE (extract);
 	TrackerExtractTask *task;
 	gchar *mimetype_used;
 
@@ -382,7 +377,6 @@ extract_task_new (TrackerExtract *extract,
 	task->file = g_strdup (uri);
 	task->mimetype = mimetype_used;
 	task->extract = extract;
-	task->max_text = priv->max_text;
 
 	if (task->res) {
 		GSource *source;
@@ -535,6 +529,9 @@ get_metadata (TrackerExtractTask *task)
 static gpointer
 single_thread_get_metadata (GAsyncQueue *queue)
 {
+	if (!tracker_seccomp_init ())
+		g_assert_not_reached ();
+
 	while (TRUE) {
 		TrackerExtractTask *task;
 
@@ -706,6 +703,9 @@ tracker_extract_get_metadata_by_cmdline (TrackerExtract             *object,
 	                                                          NULL,
 	                                                          &task->func);
 
+	if (!tracker_seccomp_init ())
+		g_assert_not_reached ();
+
 	if (!filter_module (object, task->module) &&
 	    get_file_metadata (task, &info, NULL)) {
 		resource = tracker_extract_info_get_resource (info);
@@ -736,6 +736,7 @@ tracker_extract_get_metadata_by_cmdline (TrackerExtract             *object,
 
 			g_free (text);
 		} else if (output_format == TRACKER_SERIALIZATION_FORMAT_TURTLE) {
+			TrackerNamespaceManager *namespaces;
 			char *turtle;
 
 			/* If this was going into the tracker-store we'd generate a unique ID
@@ -743,7 +744,10 @@ tracker_extract_get_metadata_by_cmdline (TrackerExtract             *object,
 			 */
 			tracker_resource_set_identifier (resource, uri);
 
-			turtle = tracker_resource_print_turtle (resource, NULL);
+			G_GNUC_BEGIN_IGNORE_DEPRECATIONS
+			namespaces = tracker_namespace_manager_get_default ();
+			G_GNUC_END_IGNORE_DEPRECATIONS
+			turtle = tracker_resource_print_rdf (resource, namespaces, TRACKER_RDF_FORMAT_TURTLE, NULL);
 
 			if (turtle) {
 				g_print ("%s\n", turtle);
@@ -784,12 +788,3 @@ tracker_extract_file_finish (TrackerExtract  *extract,
 
 	return g_task_propagate_pointer (G_TASK (res), error);
 }
-
-void
-tracker_extract_set_max_text (TrackerExtract *extract,
-                              gint            max_text)
-{
-	TrackerExtractPrivate *priv = TRACKER_EXTRACT_GET_PRIVATE (extract);
-
-	priv->max_text = max_text;
-}
